/*  This file is Copyright 2010 Hampton Smith
 *
 *  This file is part of Adventure! a text-adventure game engine by Hampton
 *  Smith.
 *
 *  Adventure! is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Adventure! is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Adventure!.  If not, see http://www.gnu.org/licenses/.
 */
package edu.clemson.cs.hamptos.adventure;

/**
 * <p>A strategy for printing out the user's current location.</p>
 */
class VerbLook implements VerbStrategy {

    /**
     * <p>By time this is called, we already know that the command is just
     * "look".  So we'll print out a description of the player's current
     * location.</p>
     *
     * @param c The command, but we know what it says.
     * @param e The engine, which we'll leave alone.
     * @param w The window, to which we'll print a description of the player's
     *    current location.
     */
    public void doCommand(AdventureCommand c, AdventureEngine e,
            AdventureWindow w) {

        AdventureLocation curLocation = e.getPlayerLocation();

        w.println(curLocation.getDescription());
    }

}
