/*  This file is Copyright 2010 Hampton Smith
 *
 *  This file is part of Adventure! a text-adventure game engine by Hampton
 *  Smith.
 *
 *  Adventure! is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Adventure! is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Adventure!.  If not, see http://www.gnu.org/licenses/.
 */

package edu.clemson.cs.hamptos.adventure;

/**
 * <p>A <code>VerbStrategy</code> simply represents a thing that can be done
 * in response to a command.  It exists to allow easy use of the Strategy
 * design pattern.</p>
 */
public interface VerbStrategy {

    /**
     * <p>Asks this strategy to do its job.  By time this is called, we've
     * already determined that this is the correct strategy to enact, so no
     * need to ever call a <code>DoNotUnderstandException</code>.</p>
     * 
     * @param c The command that got us here.  Guaranteed to be a valid command
     *    for invoking this strategy.
     * @param e The engine, in case this strategy needs to change the game
     *    world.
     * @param w The window, in case this strategy needs to print anything to the
     *    screen.
     */
    public void doCommand(AdventureCommand c, AdventureEngine e,
            AdventureWindow w);
}
